yt.analysis_modules.halo_finding.halo_objects.TextHalo.get_ellipsoid — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.TextHalo.get_ellipsoid

`TextHalo.` `get_ellipsoid`(*args, **kwargs)

  Returns an ellipsoidal data object. This will generate a new, empty ellipsoidal data object for this halo.

  Parameters: | None. :
  Returns: | ellipsoid : yt.data_objects.data_containers.YTEllipsoidBase The ellipsoidal data object.

  Examples

      >>> ell = halos[0].get_ellipsoid()